##  Step 1: Install the SAP LeanIX for Confluence App
To install the SAP LeanIX for Confluence app, follow these steps:
  1. In the top navigation bar in Confluence, go to Apps > Manage apps.
  2. Choose Find new apps and enter “SAP LeanIX for Confluence” in the search field.
  3. In the SAP LeanIX for Confluence app tile, choose Install.
